;; Generated package description from tempel.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "tempel" "1.6" "Tempo templates/snippets with in-buffer field editing" '((emacs "28.1") (compat "30")) :commit "aa0f6fab4013d4661c34f9352531ceac1f0973a8" :authors '(("Daniel Mendler" . "mail@daniel-mendler.de")) :maintainer '("Daniel Mendler" . "mail@daniel-mendler.de") :keywords '("abbrev" "languages" "tools" "text") :url "https://github.com/minad/tempel")
